{% for section, _ in sections.items() %}
{% set underline = underlines[0] %}{% if section %}{{section}}{{ underline * section|length }}{% set underline = underlines[1] %}{% endif %}
{% if sections[section] %}
{% for category, val in definitions.items() if category in sections[section]%}
{{ val['name'] }}{{ underline * val['name']|length }}

{% if definitions[category]['showcontent'] %}
{% for text, values in sections[section][category].items() %}

- {{ text }}{% for value in values %} ({{ value }}){% endfor %}

{% endfor %}
{% else %}

- {{ sections[section][category]['']|join(', ') }}

{% endif %}
{% if not loop.last %}
{% endif %}
{% endfor %}
{% else %}
No significant changes.

{% endif %}
{% endfor %}
